RESTfly: Simplifying API Libraries
==================================

**RESTfly** (pronounced restfully) is a framework for building libraries to
easily interact with RESTful APIs.

.. image:: https://github.com/librestfly/restfly/actions/workflows/testing.yml/badge.svg
   :target: https://github.com/librestfly/restfly/actions/workflows/testing.yml
.. image:: https://github.com/librestfly/restfly/actions/workflows/deploy.yml/badge.svg
   :target: https://github.com/librestfly/restfly/actions/workflows/deploy.yml
.. image:: https://img.shields.io/pypi/v/restfly.svg
   :target: https://pypi.org/project/restfly/
.. image:: https://img.shields.io/pypi/pyversions/restfly.svg
.. image:: https://img.shields.io/pypi/dm/restfly.svg
   :target: https://pypistats.org/packages/restfly
.. image:: https://img.shields.io/github/license/librestfly/restfly.svg
   :target: https://github.com/librestfly/restfly/blob/master/LICENSE
.. image:: https://sonarcloud.io/api/project_badges/measure?project=librestfly_restfly&metric=alert_status
   :target: https://sonarcloud.io/summary/overall?id=librestfly_restfly


.. image:: https://restfly.readthedocs.io/en/latest/_static/logo.png

RESTfly is a simple library designed to provide the scaffolding to make API
interaction libraries for just about any RESTful API.  With an emphasis on
simplicity and readability of the resulting library code thats written, the
idea here is provide something that is not only useful for folks to use, but
can also serve as a reference implementation of the given APIs.

Please refer to the full documentation at https://restfly.readthedocs.io.
